@@ -53,17 +53,19 @@ class SuggResult:
         # Parameters
         self.nSuggLimit = nSuggLimit
         self.nSuggLimitExt = nSuggLimit + 2             # we add few entries in case suggestions merge after casing modifications
-        self.nBestSuggLimit = floor(nSuggLimit * 1.5)   # n times the requested limit
+        self.nBestSuggLimit = floor(nSuggLimit * 2)     # n times the requested limit
         self.nGoodSuggLimit = nSuggLimit * 15           # n times the requested limit
 
     def addSugg (self, sSugg, nDeep=0):
         "add a suggestion"
-        #logging.info((nDeep * "  ") + "__" + sSugg + "__")
         if sSugg in self.aAllSugg:
             return
         self.aAllSugg.add(sSugg)
         nDistJaro = 1 - st.distanceJaroWinkler(self.sSimplifiedWord, st.simplifyWord(sSugg))
         nDist = floor(nDistJaro * 10)
+        if nDist < self.nMinDist:
+            self.nMinDist = nDist
+        #logging.info((nDeep * "  ") + "__" + sSugg + "__ " + str(round(nDistJaro*1000)))
         if nDistJaro < .11:     # Best suggestions
             self.dBestSugg[sSugg] = round(nDistJaro*1000)
             if len(self.dBestSugg) > self.nBestSuggLimit:
@@ -72,14 +74,7 @@ class SuggResult:
             self.dGoodSugg[sSugg] = round(nDistJaro*1000)
             if len(self.dGoodSugg) > self.nGoodSuggLimit:
                 self.nDistLimit = -1  # make suggest() to end search
-        else:
-            if nDist < self.nMinDist:
-                self.nMinDist = nDist
-            self.nDistLimit = min(self.nDistLimit, self.nMinDist)
-        if nDist <= self.nDistLimit:
-            if nDist < self.nMinDist:
-                self.nMinDist = nDist
-            self.nDistLimit = min(self.nDistLimit, self.nMinDist+1)
+        self.nDistLimit = min(self.nDistLimit, self.nMinDist+1)
 
     def getSuggestions (self):
         "return a list of suggestions"
@@ -103,11 +98,6 @@ class SuggResult:
             lRes = list(OrderedDict.fromkeys(map(lambda sSugg: sSugg[0:1].upper()+sSugg[1:], lRes))) # use dict, when Python 3.6+
         return lRes[:self.nSuggLimit]
 
-    def reset (self):
-        "clear data"
-        self.aSugg.clear()
-        self.dSugg.clear()
-
 
 class IBDAWG:
     """INDEXABLE BINARY DIRECT ACYCLIC WORD GRAPH"""
@@ -251,10 +241,9 @@ class IBDAWG:
         if bSplitTrailingNumbers:
             self._splitTrailingNumbers(oSuggResult, sWord)
         self._splitSuggest(oSuggResult, sWord)
+        self._suggest(oSuggResult, sWord)
         self._suggest(oSuggResult, sWord, nMaxSwitch, nMaxDel, nMaxHardRepl, nMaxJump)
         aSugg = oSuggResult.getSuggestions()
-        if self.lexicographer:
-            aSugg = self.lexicographer.filterSugg(aSugg)
         if sSfx or sPfx:
             # we add what we removed
             return list(map(lambda sSug: sPfx + sSug + sSfx, aSugg))
